#!/bin/sh
echo "Starting cubeSQL installation..."

INSTALL_DIR=/opt/cubesql

# process argument
SKIP_STARTUP=0
if [ "$1" = "-skip_startup" ]; then
    SKIP_STARTUP=1
fi

# check if installation folder exists
if [ -d  $INSTALL_DIR ]; then
	# stop server
	sudo killall -q -TERM 'cubesql'
	sleep 5
fi

#remove old installation folder (if exists)
sudo rm -Rdf $INSTALL_DIR

# create new installation folder
sudo mkdir -p $INSTALL_DIR

# copy from data to $INSTALL_DIR
sudo cp -fR ./data/* $INSTALL_DIR
sudo chown root:root "$INSTALL_DIR"
sudo chmod +x "$INSTALL_DIR/cubesql"

# install cubesqlctl
sudo cp ./data/cubesqlctl "/usr/local/bin"
sudo chmod +x "/usr/local/bin/cubesqlctl"
sudo chown root:root "/usr/local/bin/cubesqlctl"

# copy startup script
if [ $SKIP_STARTUP = 0 ]; then
	echo "Installing startup scripts..."

	# MUST be root:root
	# some distributions doesn't have the rc.d subdirectory
	INIT_DIR=/etc/rc.d/init.d
	if ! [ -d  $INIT_DIR ]; then
		INIT_DIR=/etc/init.d
	fi

	STARTUP_DIR=/etc/rc.d
	if ! [ -d  $STARTUP_DIR ]; then
		STARTUP_DIR=/etc
	fi

	sudo cp ./data/cubesql.startup "$INIT_DIR/cubesql"
	sudo chown root:root "$INIT_DIR/cubesql"

	# to make the script be run on machine start up we need to create a symbolic link to it
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc2.d/S86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc3.d/S86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc5.d/S86cubesql"

	# now the links to make cubesql shut down
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc0.d/K86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc6.d/K86cubesql"

	sudo update-rc.d -f cubesql remove
	sudo update-rc.d -f cubesql defaults

	sudo update-rc.d -f cubesql start 10 2 3 4 5 . stop 90 0 1 6 .
	# or chkconfig --add cubesql
fi

echo "cubeSQL has been successfully installed from your system."
echo ""
